#include "BlochSphereNode.h"

#include "CircleNode.h"
#include "LineNode.h"

BlochSphereNode::BlochSphereNode(const Point& location)
	: AbstractVisualNode(location, "BlochSphereNode")
{

}

void BlochSphereNode::setContent(BlochSphere* content)
{
	mContent = content;
	mContentDirty = true;
}

void BlochSphereNode::setSize(double size)
{
	if (size != mSize)
	{
		mSize = size;
		mContentDirty = true;
	}
}

void BlochSphereNode::update(SceneInfo* sceneInfo)
{
	if (!mContentDirty)
	{
		return;
	}

	mChildren.clear();

	auto loc = Point(mSize / 2.0, mSize / 2.0);
	mInnerCircle = std::make_unique<CircleNode>(loc, mSize / 2.0);
	mInnerCircle->setMinorRadius(mSize / 4.0);

	mOuterCircle = std::make_unique<CircleNode>(loc, mSize/2.0);

	mCentreCircle = std::make_unique<CircleNode>(loc, mSize / 50.0);
	mCentreCircle->setFillColor(Color(0, 0, 0));
	mCentreCircle->setHasStrokeColor(false);

	addChild(mInnerCircle.get());
	addChild(mOuterCircle.get());
	addChild(mCentreCircle.get());
}